@@ -52,7 +52,7 @@ class LingueeTranslator(BaseTranslator):
         if self._validate_payload(word):
             # %s-%s/translation/%s.html
             url = "{}{}-{}/translation/{}.html".format(self.__base_url, self._source, self._target, quote(word))
-            response = requests.get(url)
+            response = requests.get(url, verify=kwargs.get('verify'))
             soup = BeautifulSoup(response.text, 'html.parser')
             elements = soup.find_all(self._element_tag, self._element_query)
             if not elements:
@@ -73,7 +73,3 @@ class LingueeTranslator(BaseTranslator):
         return translated_words
 
 
-if __name__ == '__main__':
-    res = LingueeTranslator(source="en", target="de").translate(word='cute', return_all=False)
-    print(res)
-
