@@ -17,7 +17,7 @@ class MyMemoryTranslator(BaseTranslator):
         @param target: target language to translate to
         """
         self.__base_url = BASE_URLS.get("MYMEMORY")
-        self._source = source
+        self._source = source if source != 'auto' else 'Autodetect'
         self._target = target
 
         self.email = kwargs.get('email', None)
@@ -42,7 +42,10 @@ class MyMemoryTranslator(BaseTranslator):
             if self.email:
                 self._url_params['de'] = self.email
 
-            response = requests.get(self.__base_url, params=self._url_params, headers=self.headers)
+            response = requests.get(self.__base_url,
+                                    params=self._url_params,
+                                    headers=self.headers,
+                                    verify=kwargs.get('verify'))
             data = response.json()
             if not data:
                 raise Exception("Translation was not found in response!")
@@ -79,4 +82,3 @@ class MyMemoryTranslator(BaseTranslator):
 
         except Exception as e:
             raise e
-
