@@ -56,7 +56,7 @@ class PonsTranslator(BaseTranslator):
 
         if self._validate_payload(word):
             url = "{}{}-{}/{}".format(self.__base_url, self._source, self._target, quote(word))
-            response = requests.get(url)
+            response = requests.get(url, verify=kwargs.get('verify'))
             soup = BeautifulSoup(response.text, 'html.parser')
             elements = soup.findAll(self._element_tag, self._element_query)
             if not elements:
@@ -85,15 +85,3 @@ class PonsTranslator(BaseTranslator):
             translated_words.append(self.translate(payload=word))
         return translated_words
 
-
-if __name__ == '__main__':
-
-    # res = MyMemoryTranslator(source='auto', target='french').translate_text(path='../examples/test.txt')
-    # res = MyMemoryTranslator(source='auto', target='french').translate_sentences([
-    #     "this is good",
-    #     "das Wetter ist schön",
-    #     "un verme verde in un bicchiere verde"
-    # ])
-    # res = PonsTranslator(source="en", target="ar").translate(text='good')
-    res = PonsTranslator(source="en", target="ar").translate_words(words=('good', 'cute', 'angry'))
-    print(res)
